@@ -225,6 +225,21 @@ pub struct StarshipConfig {
     pub config: Option<Value>,
 }
 
+pub fn get_config_path() -> Option<String> {
+    if let Ok(path) = env::var("STARSHIP_CONFIG") {
+        // Use $STARSHIP_CONFIG as the config path if available
+        log::debug!("STARSHIP_CONFIG is set: {}", &path);
+        Some(path)
+    } else {
+        // Default to using ~/.config/starship.toml
+        log::debug!("STARSHIP_CONFIG is not set");
+        let config_path = utils::home_dir()?.join(".config/starship.toml");
+        let config_path_str = config_path.to_str()?.to_owned();
+        log::debug!("Using default config path: {}", config_path_str);
+        Some(config_path_str)
+    }
+}
+
 impl StarshipConfig {
     /// Initialize the Config struct
     pub fn initialize() -> Self {
@@ -241,18 +256,7 @@ impl StarshipConfig {
 
     /// Create a config from a starship configuration file
     fn config_from_file() -> Option<Value> {
-        let file_path = if let Ok(path) = env::var("STARSHIP_CONFIG") {
-            // Use $STARSHIP_CONFIG as the config path if available
-            log::debug!("STARSHIP_CONFIG is set: {}", &path);
-            path
-        } else {
-            // Default to using ~/.config/starship.toml
-            log::debug!("STARSHIP_CONFIG is not set");
-            let config_path = utils::home_dir()?.join(".config/starship.toml");
-            let config_path_str = config_path.to_str()?.to_owned();
-            log::debug!("Using default config path: {}", config_path_str);
-            config_path_str
-        };
+        let file_path = get_config_path()?;
 
         let toml_content = match utils::read_file(&file_path) {
             Ok(content) => {
