@@ -23,7 +23,7 @@ impl<'a> Default for TerraformConfig<'a> {
             symbol: "💠 ",
             style: "bold 105",
             disabled: false,
-            detect_extensions: vec!["tf", "hcl"],
+            detect_extensions: vec!["tf", "tfplan", "tfstate"],
             detect_files: vec![],
             detect_folders: vec![".terraform"],
         }
