@@ -66,10 +66,10 @@ fn parse_helm_version(helm_stdout: &str) -> Option<String> {
     // `helm version --short --client` output looks like this for Helm 2:
     // Client: v2.16.9+g8ad7037
     let version = helm_stdout
-        // split into ["v3.1.1","gafe7058"] or ["Client: v3.1.1","gafe7058"]
-        .splitn(2, '+')
+        // split into ("v3.1.1","gafe7058") or ("Client: v3.1.1","gafe7058")
+        .split_once('+')
         // return "v3.1.1" or "Client: v3.1.1"
-        .next()?
+        .map_or(helm_stdout, |x| x.0)
         // return "v3.1.1" or " v3.1.1"
         .trim_start_matches("Client: ")
         // return "v3.1.1"
